import { FlowRouter } from "meteor/ostrio:flow-router-extra";
import { i18n } from "meteor/universe:i18n";

// Prevent routing when there are unsaved changes
export const setUnsavedChanges = (unsavedChanges) => {
  sessionStorage.setItem("unsavedChanges", unsavedChanges ? "yes" : "no");
};

export const hasUnsavedChanges = () => {
  const unsavedChanges = sessionStorage.getItem("unsavedChanges");
  return unsavedChanges === "yes";
};

const preventRouteChange = (targetContext) => {
  if (hasUnsavedChanges()) {
    if (!window.confirm(i18n.__("messages.preventUnsavedChanges"))) {
      return true;
    }
    setUnsavedChanges(false);
  }
  return false;
};

FlowRouter.triggers.exit([
  function (context, redirect, stop) {
    if (preventRouteChange(context)) {
      stop();
    }
  },
]);

FlowRouter.triggers.enter([
  function (context, redirect, stop) {
    setUnsavedChanges(false);
  },
]);

// Catch window close
const confirmExit = (event) => {
  if (hasUnsavedChanges()) {
    const confirmationMessage = i18n.__("messages.preventUnsavedChanges");
    (event || window.event).returnValue = confirmationMessage; //Gecko + IE
    return confirmationMessage; //Gecko + Webkit, Safari, Chrome etc.
  }
};
window.onbeforeunload = confirmExit;
